@@ -1,5 +1,5 @@
 use nxui::natives_and_messaging::{AWS_UTILITY, WS_NORMAL};
-use nxui::window::{AdvancedOptions, Application, Frame, Attributes};
+use nxui::window::{AdvancedOptions, Application, Attributes, Frame};
 
 fn main() {
     nxui::initialize();
@@ -7,15 +7,11 @@ fn main() {
     nxui::nxui::create_new_app(Box::new(app));
 }
 
-struct UtilityApplication {
-
-}
+struct UtilityApplication {}
 
 impl UtilityApplication {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
 }
 
@@ -25,7 +21,7 @@ impl Application for UtilityApplication {
     }
 
     fn attributes(&self) -> Attributes {
-        Attributes::new(WS_NORMAL, "Utility Window".to_string(),400, 675, 100, 100)
+        Attributes::new(WS_NORMAL, "Utility Window".to_string(), 400, 675, 100, 100)
     }
 
     fn is_child_window(&self) -> bool {
@@ -39,4 +35,4 @@ impl Application for UtilityApplication {
     fn ui(&self, frame: Frame) {
         frame.show();
     }
-}
\ No newline at end of file
+}
