@@ -11,15 +11,11 @@ fn main() {
     nxui::nxui::create_new_app(Box::new(win));
 }
 
-struct WidgetWindow {
-
-}
+struct WidgetWindow {}
 
 impl WidgetWindow {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
 }
 
@@ -29,7 +25,15 @@ impl Application for WidgetWindow {
     }
 
     fn attributes(&self) -> Attributes {
-        Attributes::new(WS_NORMAL, "Widget Window".to_string(),"io.github.lattesyobon.widget".to_string(),1280, 750, 100, 100)
+        Attributes::new(
+            WS_NORMAL,
+            "Widget Window".to_string(),
+            "io.github.lattesyobon.widget".to_string(),
+            1280,
+            750,
+            100,
+            100,
+        )
     }
 
     fn is_child_window(&self) -> bool {
@@ -42,18 +46,90 @@ impl Application for WidgetWindow {
         use nxui::widget::label::Label;
         use nxui::widget::radiobutton::RadioButton;
         use nxui::widget::textedit::TextEdit;
-        Label::new(Attributes::new(WS_NORMAL, "Button Controls".to_string(), "".to_string(),350, 250, 50, 50), frame).show();
+        Label::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Button Controls".to_string(),
+                "".to_string(),
+                350,
+                250,
+                50,
+                50,
+            ),
+            frame,
+        )
+        .show();
 
-        Button::new(Attributes::new(WS_NORMAL, "Push Button".to_string(), "".to_string(),350, 250, 100, 100), frame).show();
-        CheckBox::new(Attributes::new(WS_NORMAL, "Check Box".to_string(), "".to_string(),150, 250, 500, 100), frame).show();
-        RadioButton::new(Attributes::new(WS_NORMAL, "Radio Button".to_string(), "".to_string(),250, 250, 650, 100), frame).show();
+        Button::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Push Button".to_string(),
+                "".to_string(),
+                350,
+                250,
+                100,
+                100,
+            ),
+            frame,
+        )
+        .show();
+        CheckBox::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Check Box".to_string(),
+                "".to_string(),
+                150,
+                250,
+                500,
+                100,
+            ),
+            frame,
+        )
+        .show();
+        RadioButton::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Radio Button".to_string(),
+                "".to_string(),
+                250,
+                250,
+                650,
+                100,
+            ),
+            frame,
+        )
+        .show();
 
-        Label::new(Attributes::new(WS_NORMAL, "Text Edit".to_string(), "".to_string(),350, 50, 50, 400), frame).show();
-        TextEdit::new(Attributes::new(WS_NORMAL, "Text Edit".to_string(), "".to_string(),550, 200, 50, 450), frame).show();
+        Label::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Text Edit".to_string(),
+                "".to_string(),
+                350,
+                50,
+                50,
+                400,
+            ),
+            frame,
+        )
+        .show();
+        TextEdit::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Text Edit".to_string(),
+                "".to_string(),
+                550,
+                200,
+                50,
+                450,
+            ),
+            frame,
+        )
+        .show();
 
         // Initialize Menu
         let menu = initialize_menu();
-        frame.set_menu(menu);
+        frame.clone().set_menu(menu);
 
         frame.show();
     }
@@ -80,7 +156,6 @@ fn initialize_menu() -> MenuBar {
     file_menu.add_separator();
     file_menu.add_menuitem(exit_item);
 
-
     // Initialize Edit Menu
     let undo_item = MenuItem::new("Undo");
     let redo_item = MenuItem::new("Redo");
@@ -96,4 +171,4 @@ fn initialize_menu() -> MenuBar {
     let about_item = MenuItem::new("About this Sample");
     help_menu.add_menuitem(about_item);
     menu_bar
-}
\ No newline at end of file
+}
