@@ -1,8 +1,8 @@
 //! Displays an OS-specific message dialog.
 //! Display OS-specific dialogs in Windows environment, and GTK dialogs in Linux environment.
 
-use std::iter::once;
 use crate::window::Frame;
+use std::iter::once;
 
 #[cfg(windows)]
 pub struct MessageBox<'a> {
@@ -56,7 +56,10 @@ impl<'a> MessageBox<'a> {
     ///     MessageBox::new("Hello NXUI!".to_string(),"This is a test".to_string(),DIALOGSTYLE_INFORMATION,BUTTONSTYLE_OK).show();
     /// }
     /// ```
-    pub fn show(&self,frame: Frame) -> windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_RESULT {
+    pub fn show(
+        &self,
+        frame: Frame,
+    ) -> windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_RESULT {
         unsafe {
             use windows_sys::{
                 Win32::Foundation::*, Win32::System::Threading::*,
@@ -66,22 +69,30 @@ impl<'a> MessageBox<'a> {
             SetEvent(event);
             WaitForSingleObject(event, 0);
             CloseHandle(event);
-            info!("HANDLE: {}",frame.get_window());
+            info!("HANDLE: {}", frame.get_window());
 
             let result = MessageBoxW(
                 frame.get_window(),
-                self.message.encode_utf16().chain(once(0)).collect::<Vec<u16>>().as_mut_ptr(),
-                self.title.encode_utf16().chain(once(0)).collect::<Vec<u16>>().as_mut_ptr(),
+                self.message
+                    .encode_utf16()
+                    .chain(once(0))
+                    .collect::<Vec<u16>>()
+                    .as_mut_ptr(),
+                self.title
+                    .encode_utf16()
+                    .chain(once(0))
+                    .collect::<Vec<u16>>()
+                    .as_mut_ptr(),
                 self.style | self.button_style,
             );
-            info!("The Result of MessageBox is {}",result);
+            info!("The Result of MessageBox is {}", result);
             result
         }
     }
 }
 
 #[cfg(unix)]
-impl <'a> MessageBox<'a> {
+impl<'a> MessageBox<'a> {
     /// Create a new MessageBox.
     pub fn new(
         title: &'a str,
@@ -108,7 +119,7 @@ impl <'a> MessageBox<'a> {
     ///     MessageBox::new("Hello NXUI!".to_string(),"This is a test".to_string(),DIALOGSTYLE_INFORMATION,BUTTONSTYLE_OK).show();
     /// }
     /// ```
-    pub fn show(&self,frame: Frame) -> gtk::ResponseType {
+    pub fn show(&self, frame: Frame) -> gtk::ResponseType {
         use gtk::prelude::*;
         gtk::init().expect("Failed to initialize gtk.");
         let window = frame.get_window();
