@@ -1,7 +1,4 @@
 //! Constants for communicating with the OS about dialog styles, etc.
-//! What starts with DIALOGSTYLE is Constants that set the dialog icon information.
-//! What starts with BUTTONSTYLE is a constant for changing the buttons in the dialog.
-
 
 pub type FileChooserStyle = i32;
 pub type WidgetStyle<'a> = &'a str;
@@ -106,10 +103,12 @@ pub const DR_CANCEL: gtk::ResponseType = gtk::ResponseType::Cancel;
 
 #[cfg(windows)]
 /// Standard window
-pub const WS_NORMAL: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_OVERLAPPEDWINDOW;
+pub const WS_NORMAL: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE =
+    windows_sys::Win32::UI::WindowsAndMessaging::WS_OVERLAPPEDWINDOW;
 #[cfg(windows)]
 /// A window with only a close button
-pub const WS_ONLYEXIT: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_SYSMENU;
+pub const WS_ONLYEXIT: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE =
+    windows_sys::Win32::UI::WindowsAndMessaging::WS_SYSMENU;
 
 #[cfg(unix)]
 /// Standard window
@@ -119,28 +118,28 @@ pub const WS_NORMAL: gtk::WindowType = gtk::WindowType::Toplevel;
 pub const WS_NOCAPTION: gtk::WindowType = gtk::WindowType::Popup;
 
 #[cfg(windows)]
-pub const AWS_UTILITY: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_EX_TOOLWINDOW;
+pub const AWS_UTILITY: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE =
+    windows_sys::Win32::UI::WindowsAndMessaging::WS_EX_TOOLWINDOW;
 #[cfg(unix)]
 pub const AWS_UTILITY: gtk::gdk::WindowTypeHint = gtk::gdk::WindowTypeHint::Utility;
 
 /// File Chooser Attributes
 #[cfg(windows)]
-pub const FC_NONE:winapi::shared::minwindef::DWORD = 0;
+pub const FC_NONE: winapi::shared::minwindef::DWORD = 0;
 #[cfg(unix)]
 pub const FC_NONE: FileChooserStyle = 0;
 #[cfg(windows)]
-pub const FC_DISABLE_READ_ONLY:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_HIDEREADONLY;
+pub const FC_DISABLE_READ_ONLY: winapi::shared::minwindef::DWORD =
+    winapi::um::commdlg::OFN_HIDEREADONLY;
 #[cfg(unix)]
 pub const FC_DISABLE_READ_ONLY: FileChooserStyle = 0;
 /// Windows Only
 #[cfg(windows)]
-pub const FC_NEW_EXPLORER:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_EXPLORER;
+pub const FC_NEW_EXPLORER: winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_EXPLORER;
 #[cfg(windows)]
-pub const FC_ENABLE_HELP:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_SHOWHELP;
+pub const FC_ENABLE_HELP: winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_SHOWHELP;
 
-
-
-#[deprecated(since="0.15.2", note="Please use the respective widget structure")]
-pub const WT_BUTTON:WidgetStyle = "BUTTON\0";
-#[deprecated(since="0.15.2", note="Please use the respective widget structure")]
-pub const WT_TEXTEDIT:WidgetStyle = "EDIT\0";
\ No newline at end of file
+#[deprecated(since = "0.15.2", note = "Please use the respective widget structure")]
+pub const WT_BUTTON: WidgetStyle = "BUTTON\0";
+#[deprecated(since = "0.15.2", note = "Please use the respective widget structure")]
+pub const WT_TEXTEDIT: WidgetStyle = "EDIT\0";
