@@ -19,8 +19,16 @@ pub fn create_new_app(application: Box<dyn Application>) {
     application.startup(storage);
 
     // Create a window
-    use windows_sys::{Win32::Foundation::*, Win32::UI::WindowsAndMessaging::*,Win32::System::LibraryLoader::GetModuleHandleA};
-    extern "system" fn wndproc(window: HWND, message: u32, wparam: WPARAM, lparam: LPARAM) -> LRESULT {
+    use windows_sys::{
+        Win32::Foundation::*, Win32::System::LibraryLoader::GetModuleHandleA,
+        Win32::UI::WindowsAndMessaging::*,
+    };
+    extern "system" fn wndproc(
+        window: HWND,
+        message: u32,
+        wparam: WPARAM,
+        lparam: LPARAM,
+    ) -> LRESULT {
         unsafe {
             match message as u32 {
                 WM_DESTROY => {
@@ -53,13 +61,26 @@ pub fn create_new_app(application: Box<dyn Application>) {
 
         let atom = RegisterClassA(&wc);
         debug_assert!(atom != 0);
-        let win = CreateWindowExA(application.advanced_options().get_style(), "window".as_ptr(), format!("{}\0",attributes.title).as_ptr(), attributes.style|WS_VISIBLE, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
+        let win = CreateWindowExA(
+            application.advanced_options().get_style(),
+            "window".as_ptr(),
+            format!("{}\0", attributes.title).as_ptr(),
+            attributes.style | WS_VISIBLE,
+            attributes.x,
+            attributes.y,
+            attributes.width,
+            attributes.height,
+            0,
+            0,
+            instance,
+            std::ptr::null_mut(),
+        );
         if win == 0 {
             MessageBox::new("NXUI Error", "NXUI Error - Code 0001\rWindow could not be initialized\r \rDetailed information:\rPanicked at nxui::nxui::create_new_app()\rTo resolve this error, contact the application developer or\rPlease report at https://github.com/LatteSyobon/nxui/issues", DS_ERROR, BS_OK).show(Frame::default());
             panic!("Window could not be initialized");
         }
 
-        info!("A window has been created. handle: {}",win);
+        info!("A window has been created. handle: {}", win);
 
         let frame = Frame::new(win);
         info!("Frame has been created.");
@@ -97,24 +118,24 @@ pub fn create_new_app(application: Box<dyn Application>) {
     use gtk::prelude::*;
 
     let app = gtk::Application::new(Option::from(attributes.app_id.as_str()), Default::default());
-	app.connect_activate(move |app: &gtk::Application| {
-		let window = gtk::ApplicationWindow::new(app);
-		info!("A window has been created. handle: {}",window);
+    app.connect_activate(move |app: &gtk::Application| {
+        let window = gtk::ApplicationWindow::new(app);
+        info!("A window has been created. handle: {}", window);
 
-		window.set_title(attributes.title.as_str());
-		window.set_default_size(attributes.width,attributes.height);
-		window.set_window_position(gtk::WindowPosition::Center);
-		window.set_type_hint(advanced_options.get_style());
-		
-		let frame = Frame::new(window.clone(),window.application());
-		info!("Frame has been created.");
-		info!("UI Phase");
-		application.ui(&frame);
+        window.set_title(attributes.title.as_str());
+        window.set_default_size(attributes.width, attributes.height);
+        window.set_window_position(gtk::WindowPosition::Center);
+        window.set_type_hint(advanced_options.get_style());
 
-		window.show_all();
-	});
+        let frame = Frame::new(window.clone(), window.application());
+        info!("Frame has been created.");
+        info!("UI Phase");
+        application.ui(&frame);
+
+        window.show_all();
+    });
 
     app.run();
     //info!("UI Exit");
     //application.exit();
-}
\ No newline at end of file
+}
