@@ -1,3 +1,5 @@
+//! Dialog type window.
+
 use crate::window::{Attributes, Frame};
 
 pub trait Dialog {
@@ -5,15 +7,23 @@ pub trait Dialog {
 
     fn frame(&self) -> Frame;
 
-    fn ui(&self,frame: Frame);
+    fn ui(&self, frame: Frame);
 }
 
 #[cfg(windows)]
 pub fn create_dialog(dialog: Box<dyn Dialog>) {
     let attributes = dialog.attributes();
     let frame = dialog.frame();
-    use windows_sys::{Win32::Foundation::*, Win32::UI::WindowsAndMessaging::*,Win32::System::LibraryLoader::GetModuleHandleA};
-    extern "system" fn wndproc(window: HWND, message: u32, wparam: WPARAM, lparam: LPARAM) -> LRESULT {
+    use windows_sys::{
+        Win32::Foundation::*, Win32::System::LibraryLoader::GetModuleHandleA,
+        Win32::UI::WindowsAndMessaging::*,
+    };
+    extern "system" fn wndproc(
+        window: HWND,
+        message: u32,
+        wparam: WPARAM,
+        lparam: LPARAM,
+    ) -> LRESULT {
         unsafe {
             match message as u32 {
                 WM_DESTROY => {
@@ -45,7 +55,20 @@ pub fn create_dialog(dialog: Box<dyn Dialog>) {
 
         let _atom = RegisterClassA(&wc);
 
-        let win = CreateWindowExA(0, "window".as_ptr(), attributes.title.as_ptr(), WS_SYSMENU, attributes.x, attributes.y, attributes.width, attributes.height, frame.get_window(), 0, instance, std::ptr::null_mut());
+        let win = CreateWindowExA(
+            0,
+            "window".as_ptr(),
+            attributes.title.as_ptr(),
+            WS_SYSMENU,
+            attributes.x,
+            attributes.y,
+            attributes.width,
+            attributes.height,
+            frame.get_window(),
+            0,
+            instance,
+            std::ptr::null_mut(),
+        );
 
         let dialog_frame = Frame::new(win);
         dialog.ui(dialog_frame);
@@ -69,15 +92,15 @@ pub fn create_dialog(dialog: Box<dyn Dialog>) {
     let window = gtk::ApplicationWindow::new(&app);
 
     window.set_title(attributes.title.as_str());
-    window.set_default_size(attributes.width,attributes.height);
+    window.set_default_size(attributes.width, attributes.height);
     window.set_window_position(gtk::WindowPosition::Center);
     window.set_type_hint(gtk::gdk::WindowTypeHint::Utility);
 
-    let dialog_frame = Frame::new(window.clone(),window.application());
+    let dialog_frame = Frame::new(window.clone(), window.application());
 
     dialog.ui(dialog_frame);
 
     window.show_all();
 
     app.run();
-}
\ No newline at end of file
+}
